#
# spec file for package fwts
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           fwts
Version:        16.12.00
Release:        1.1
Summary:        Firmware Test Suite
License:        GPL-2.0+
Group:          Development/Tools/Other
Url:            https://wiki.ubuntu.com/Kernel/Reference/fwts
Source0:        http://fwts.ubuntu.com/release/%{name}-V%{version}.tar.gz
# PATCH-FIX-OPENSUSE fwts-no-compiletime.patch
Patch1:         fwts-no-compiletime.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(json)
BuildRequires:  pkgconfig(libpci)
BuildRequires:  pkgconfig(libpcre)
Recommends:     acpica
Recommends:     dmidecode
Recommends:     pciutils

%description
The FirmWare Test Suite (fwts) is a tool to do automatic testing of a PC's
firmware. There can be a lot of subtle or vexing Linux Kernel/firmware issues
caused when firmware is buggy, so it's useful to have a tool that can
automatically check for common BIOS and ACPI errors. Where possible the tool
will give some form of advice on how to fix issues or workaround firmware
issues.

%prep
%setup -q -c %{name}-%{version}
%patch1

%build
autoreconf -fiv
%configure \
	--disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
install -D -p -m 0644 data/klog.json %{buildroot}%{_datadir}/%{name}/klog.json
install -D -p -m 0644 data/syntaxcheck.json %{buildroot}%{_datadir}/%{name}/syntaxcheck.json
# There are no headers, so drop remaining development files
rm -f "%{buildroot}/%{_libdir}/%{name}"/*.so

%files
%defattr(-,root,root)
%doc README
%{_bindir}/fwts
%{_bindir}/kernelscan
%{_libdir}/fwts
%{_mandir}/man1/fwts-collect.1%{ext_man}
%{_mandir}/man1/fwts-frontend-text.1%{ext_man}
%{_mandir}/man1/fwts.1%{ext_man}
%dir %{_datadir}/%{name}
%{_datadir}/fwts/klog.json
%{_datadir}/fwts/syntaxcheck.json
%{_datadir}/fwts/olog.json

%changelog
* Mon Jan  2 2017 mpluskal@suse.com
- Update to version 0.6.12 (boo#1017763):
  * ACPICA: Update to version 20161117
  * klog.json: Add a few more kernel errors to the database
  * opal: pci_info: Add OPAL PCI Info validation
  * opal: mem_info: Add OPAL MEM Info validation
  * opal: cpu_info: Add OPAL CPU Info validation
  * securebootcert: add variable AuditMode checking
  * securebootcert: add variable DeployedMode checking
  * lots of bugfixes
* Thu Dec  1 2016 mpluskal@suse.com
- Replace requires with recommends for dependencies
* Sun Nov 13 2016 mpluskal@suse.com
- Update to version 06.11.00:
  * ACPICA: Update to version 20160930
  * uefibootpath: add test for eMMC device path
  * uefidump: add dumping for the eMMC device path
  * miscelanous bugfixes
* Sun Sep 11 2016 mpluskal@suse.com
- Update to version 06.09.00:
  * lib: acpi: add supports for WPBT
  * acpi: wpbt: add ACPI WPBT test
  * lib: acpi: add supports for DRTM
  * acpi: drtm: add ACPI DRTM test
  * lib: fwts_guid: add a compare function
  * acpi: nfit: check fields equals 0 for Virtual CD and Disk
  * opal: mtd: Add OPAL MTD Validation
  * acpi: ACPI Platform check updates
  * acpi: fadt: Remove HEADLESS check on reduced hardware
  * pci: aspm: Add segment support
  * ACPICA: Update to version 20160831
  * lots of bugs fixed
- Drop no longer needed json-c-includes.patch
- Exclude s390x from building
* Thu Aug 18 2016 mpluskal@suse.com
- Update to version 16.08.00 (boo#994319):
  * acpi: nfit: add ACPI NFIT test
  * lib: acpi: add support for MPST
  * acpi: mpst: add ACPI MPST test
  * lib: acpi: add support for PMTT
  * acpi: pmtt: add ACPI PMTT test
  * ACPICA: Update to version 20160729
  * lots of bugfixes
* Sun Jul 31 2016 mpluskal@suse.com
- Update to version 16.07.00:
  * --uefi and --acpi options renamed to --uefitests and
  - -acpitests
  * ACPI table tests in the acpitables test have been moved into
    specific ACPI tests.
  * cpi: acpidump: update TCPA table and acpidump accordingly
  * acpi: add ACPI TCPA test
  * acpi: add XENV table test
  * lib: fwts_framework: Append "tests" to --uefi and --acpi
  * live-image/fwts-frontend-text: update to --uefitests and
  - -acpitests
  * lib: acpi, acpidump: rename slit tables types
  * lib: acpi: add in new GICC table fwts_acpi_table_gicc_affinity
  * acpi: add SRAT table sanity checking (LP: #1464658)
  * acpi: add BERT table sanity checking (LP: #1464712)
  * lib: acpi: Add in GAS address types
  * acpi: add ECDT table sanity checking (LP: #1464716)
  * lib: acpi: Add support for the SPMI table
  * acpi: add ACPI SPMI table sanity checking (LP: #1465256)
  * acpi: add ACPI SLIT table sanity checking (LP: #1465276)
  * lib: acpi: Add support for the HEST family of ACPI tables
  * acpi: add ACPI HEST table sanity checking (LP: #1465379)
  * acpi: Add BOOT table test (LP: #1465435)
  * acpi: Add DBGP table test (LP: #1465441)
  * acpi: Add DBG2 table test (LP: #1465710)
  * acpi: re-orgainise HPET tests
  * acpi: move MADT test from acpitables into new MADT test
  * acpi: move GTDT test from acpitables into new GTDT test
  * acpi: move XSDT test from acpitables into new XSDT test
  * acpi: move RSDP test from acpitables into new RSDP test
  * acpi: move RSDT test from acpitables into new RSDT test
  * acpi: acpitables: remove no-op MCFG test
  * acpi: move SBST test from acpitables into new SBST test
  * acpi: move FADT test from acpitables into existing FADT test
  * acpi: acpitables: remove redundant acpi table checking
  * acpi: allow various ACPI table tests to run without root access
  * lib: fwts_acpi_tables: fully pad out fixed up ACPI OEM IDs
  * acpi: spcr: add missing white space in error messages
  * acpi: add ACPI ERST test (LP: #1467835)
  * acpi: correct ACPI BGRT table type
  * acpi: add ACPI BGRT test (LP: #1467863)
  * acpi: add ACPI CPEP test (LP: #1467870)
  * acpi: add ACPI FACS test (LP: #1467966)
  * acpi: acpidump: add in missing exponent field to SLIC
  * acpi: add CSRT ACPI Table test (LP: #1470116)
  * acpi: add LPIT ACPI test (LP: #1470184)
  * acpi: add WAET ACPI table test (LP: #1470495)
  * acpi: add SLIC table test (LP: #1470518)
  * acpi: add MSDM table test (LP: #1470538)
  * acpi: add UEFI ACPI data table test (LP: #1471698)
  * bios: os2gap: remove ancient legacy test (LP: #1470573)
  * lost of bugfixes
* Sat Jul 16 2016 mpluskal@suse.com
- Update to version 16.06.01:
  * lib: acpi: add an acpi category
  * live-image/fwts-frontend-text: add selections of acpi and uefi
    tests
  * acpi: add tests to acpi category
  * acpi: fwts-tests: Remove redundant tailing space and update
    fwts-tests
  * auto-packager: mkpackage.sh: remove lucid
  * auto-packager: mkpackage.sh: add wily
  * acpi: Add SPCR ACPI table check (LP: #1433604)
  * dmi: dmicheck: add 4 new DMI chassis types
  * lots of bugfixes
- Enable building on all architectures
* Wed May 18 2016 mpluskal@suse.com
- Update to version 16.05.01:
  * ACPICA: Update to version 20160108 (LP: #1532268)
  * acpi: method: add _PTC test
  * sync with uefi 2.5 global variables
    + uefidump: add dumping global variabl AuditMode
    + uefidump: add dumping global variabl DeployedMode
    + uefidump: add dumping global variable OsRecoveryOrder
    + uefidump: add dumping global variable PlatformRecovery####
    + uefidump: add dumping global variable SysPrepOrder
    + uefidump: add dumping global variable SysPrep####
  * ACPICA: Update to version 20151218 (LP: #1527733)
  * esrtdump: add dumping for esrt table (LP: #1532103)
  * Fix spelling mistakes of "ACPI"
  * method: update method status
  * utilities: kernelscan: fix memory leaks and a segfault
  * acpi: cstates: fix clang build warning on zero CPUs.
  * acpi: s3, s3power, s4: replace cleanup free with explicit frees
  * data: klog.json: add in some more kernel error messages for 4.4
    (LP: #1526746)
  * acpi: hpet: fwts_mmap failure is FWTS_MAP_FAILED and not NULL
  * acpi: pcc: fwts_mmap failure is FWTS_MAP_FAILED and not NULL
  * bios: ebdadump: fwts_mmap failure is FWTS_MAP_FAILED and not
    MAP_FAILED
  * acpi: syntaxcheck: ASL_MSG_COMPILER_RESERVED failure should be
    an info (LP: #1529717)
  * Update copyright year to 2016
  * dmi: dmicheck: fix reserved bits mask for Processor Information
  * uefirtvariable: fix decalred VLA have zero size (LP: #1526815)
* Thu Mar 17 2016 mpluskal@suse.com
- Update to 16.03.00
  * acpi: method: add _PTC test
  * sync with uefi 2.5 global variables
    + uefidump: add dumping global variabl AuditMode
    + uefidump: add dumping global variabl DeployedMode
    + uefidump: add dumping global variable OsRecoveryOrder
    + uefidump: add dumping global variable PlatformRecovery####
    + uefidump: add dumping global variable SysPrepOrder
    + uefidump: add dumping global variable SysPrep####
    + ACPICA: Update to version 20151218 (LP: #1527733)
    + esrtdump: add dumping for esrt table (LP: #1532103)
  * Fix spelling mistakes of "ACPI"
  * method: update method status
  * utilities: kernelscan: fix memory leaks and a segfault
  * acpi: cstates: fix clang build warning on zero CPUs.
  * acpi: s3, s3power, s4: replace cleanup free with explicit frees
  * data: klog.json: add in some more kernel error messages for 4.4
    (LP: #1526746)
  * acpi: hpet: fwts_mmap failure is FWTS_MAP_FAILED and not NULL
  * acpi: pcc: fwts_mmap failure is FWTS_MAP_FAILED and not NULL
  * bios: ebdadump: fwts_mmap failure is FWTS_MAP_FAILED and not
    MAP_FAILED
  * acpi: syntaxcheck: ASL_MSG_COMPILER_RESERVED failure should be
    an info (LP:#1529717)
  * Update copyright year to 2016
  * dmi: dmicheck: fix reserved bits mask for Processor
    Information
  * uefirtvariable: fix decalred VLA have zero size (LP: #1526815)
* Thu Feb 25 2016 mpluskal@suse.com
- Update to 16.02.00
  * Start defining FWTS architectures as variables
  * Define some utility functions for using the fwts_architecture
    enum
  * Add mechanism to tell FWTS what architecture is being tested
  * ACPI: MADT: add in compliance tests for the MADT and subtables
  * ACPI: Add in MADT subtable description for GIC ITS subtable
  * ACPI: MADT: add in compliance checks for the GIC ITS subtable
  * Documentation: add --acpicompliance to man page
  * Documentation: add --arch to the man page
  * RSDP: minor cleanups to rsdp.c for checkpatch issues
  * utilities: add a helper function for printing out architecture
    names
  * ACPI tables: when bodging up an RSDP, do the right thing for
    the arch
  * ACPI RSDP: flesh out the tests to check for full spec
    compliance.
  * Update regression test rsdp-0001/test-0001.sh
  * Update the regression test arg-help-0001/test-0001.sh
  * Update regression test for arg-help-0001/test-0002.sh
  * Update regression test for arg-show-tests-0001/test-0001.sh
  * Update regression test arg-show-tests-full-0001/test-0001.sh
  * Update the regression test arg-table-path-0001/test-0001.sh
  * Update the regression test madt-0001/test-0001.sh
  * Update the regression test madt-0001/test-0002.sh
  * FADT: enable compiling on non-x86 architectures
  * FADT: non-x86 machines need an FADT but x86 can survive
    without one
  * FADT: disable SCI_EN and RESET_REG tests when in reduced
    hardware mode
  * FADT: add in code to log basic info about the various FADT
    flag fields
  * Add in bit masks for FACS flags.
  * FADT: move log info out of test2, will provide it elsewhere
  * ACPI: Add hypervisor ID field to FADT.
  * FADT: minor cleanup and initial compliance tests
  * FADT: expand the compliance test for FIRMWARE_CTRL fields
  * FADT: expand compliance checks for DSDT and X_DSDT fields
  * FADT: add compliance tests for reserved fields, PM profile,
    reduced hardware
  * FADT: restructure test sequence around reduced hardware mode
  * FADT: expand compliance tests for the SMI_CMD field
  * FADT: add compliance tests for the ACPI_ENABLE and
    ACPI_DISABLE fields
  * FADT: add compliance tests for S4BIOS_REQ and PSTATE_CNT
    fields
  * FADT: extend and add PM address block compliance tests
  * FADT: enhance compliance tests for GPE blocks
  * FADT: add compliance test for the CST_CNT field
  * FADT: add in compliance tests for C2/C3 latency fields
  * FADT: add in SLEEP_CONTROL_REG and SLEEP_STATUS_REG
    compliance tests
  * FADT: remove no longer useful variables from test1
  * FADT: add safety checks for older versions of FADT
  * FADT: update regression tests to incorporate new/changed
    tests
  * acpi: method: add _PMC test
  * acpi: method: add _PRT test
  * fwts-test: update for _PMC and _PRT tests
  * acpi: method: add _RDI test
  * acpi: method: add _LPI test
  * fwts-test: update for _RDI and _LPI tests
  * acpi: method: remove non-method names from the top comments
  * acpi: erst: fix incorrect error message for reserved field
  * fwts-test: update erst test for the fix of reserved field
  * lib: fwts_klog: fix incorrect indentation, detected by gcc-6
  * lib: fwts_hwinfo: clean up type punning, fixes warning with
    gcc-6
  * fwts: wakealarm: reset wakealarm timer at end of test
    (LP: #1534003)
  * Update arg-show-tests-full now that we have an extra test in
    wakealarm
  * dmi: dmicheck: add some simple sanity checks to table size
  * lib: fwts_args: use safer strncat than strcat
  * lib: fwts_acpi_tables: don't do expensive low allocs multiple
    times
  * acpi: fadt: check 32/64 bit PM register addresses for
    inconsistency (LP: #1536606)
  * acpi: madt: fix incorrect format specifier for size_t
  * cpu: microcode: fix a couple of warnings found by cppcheck:
  * acpi: madt: clean up some minor style issues detected by
    cppcheck
  * data: klog.json: update to sync with 4.6 kernel changes
  * ACPICA: Update to version 20160212 (LP: #1545099)
  * lib: fwts_acpi_tables: fix warnings found by clang scan-build
  * lib: fwts_cpu: check for MSR read failures
  * lib: fwts_klog: handle the case where klog_old is empty list
  * acpica: fix disassembly on i386 platforms (LP: #1547469)
  * lib: fwts_arch: i686 arch name is also an X86 arch
    (LP: #1547554)
  * fwts-test: only run rsdp regression test on specific arches
    (LP: #1547602)
  * Fix null_gass initializer for older versions of gcc
    (LP: #1549429)
  * fwts-test: sync up with the arg-table-path
* Sun Jan 17 2016 mpluskal@suse.com
- Update to 16.01.00
  * ACPICA: Update to version 20160108
  * acpi: method: add _PTC test
  * sync with uefi 2.5 global variables
    + uefidump: add dumping global variabl AuditMode
    + uefidump: add dumping global variabl DeployedMode
    + uefidump: add dumping global variable OsRecoveryOrder
    + uefidump: add dumping global variable PlatformRecovery####
    + uefidump: add dumping global variable SysPrepOrder
    + uefidump: add dumping global variable SysPrep####
  * ACPICA: Update to version 20151218
  * esrtdump: add dumping for esrt table
  * fixed bugs:
    + Fix spelling mistakes of "ACPI"
    + method: update method status
    + utilities: kernelscan: fix memory leaks and a segfault
    + acpi: cstates: fix clang build warning on zero CPUs.
    + acpi: s3, s3power, s4: replace cleanup free with explicit
    frees
    + data: klog.json: add in some more kernel error messages for
    4.4
    + acpi: hpet: fwts_mmap failure is FWTS_MAP_FAILED and not NULL
    + acpi: pcc: fwts_mmap failure is FWTS_MAP_FAILED and not NULL
    + bios: ebdadump: fwts_mmap failure is FWTS_MAP_FAILED and not
    MAP_FAILED
    + acpi: syntaxcheck: ASL_MSG_COMPILER_RESERVED failure should
    be an info
    + Update copyright year to 2016
    + dmi: dmicheck: fix reserved bits mask for Processor
    Information
    + uefirtvariable: fix decalred VLA have zero size
* Sat Dec 19 2015 mpluskal@suse.com
- Update to 05.12.00
  * Update ACPICA to version 20151124
  * live-image/fwts-frontend-text: add a selection for recommended
  * data: klog.json: add in some more kernel error messages for
  4.3
  * ACPI: Add ASPT test
  * lib: framework: allow mixed tests and test category options
  * fwts: framework: Add --log-level option
  * lib: fwts_uefi: add SD device path define
  * Boot path sync with UEFI spec. 2.5
  + uefibootpath: add test for the SD device path
  + uefidump: add dumping for the SD device path
  + lib: fwts_uefi: add efi bluetooth device path define
  + uefibootpath: add test for the bluetooth device path
  + uefidump: add dumping for the bluetooth device path
  + lib: fwts_uefi: add wireless device path define
  + uefibootpath: add test for the wireless device path
  + uefidump: add dumping for the wireless device path
  + lib: fwts_uefi: add ramdisk device path define
  + uefibootpath: add test for the ramdisk device path
  + uefidump: add dumping for the ramdisk device path
  * Fixed bugs
  + acpi: fpdt: add a terminate for buggy BIOS that reports zero
  length
  + lib: klog: remove use of pcre, use regex instead
  + utilities: kernelscan: remove use of pcre, use regex instead
  + uefidump: add more bounds checking and remove need for heap
  + utilities: fix memory leak, line not being free'd
  + acpi: bert: remove redundant variable 'length'
  + lib: iasl: rework IASL interface to ACPICA
  + acpi: acpidump: use IASL rather than fwts custom table dump
  code
  + s3 + klog: make log scanning more robust for S3 (LP: #1522292)
  + lib: acpica: make region handler more robust (LP: #1524217)
  + debian: copyright, fix lintian warnings
  + Debian: update Standards-Version to 3.9.6
  + acpi: acpidump: check for fwts_iasl_init failure
  + lib: fwts_acpi_tables: fix segfault when tables fail to load
  (LP: #1452201)
  + acpi: dbg2: remove dead store to ptr1
  + hotkey: fix key reading loop, it needs to loop more than once
  + lib: fwts_framework: remove dead store to len in for loop
  + lib: fwts_acpi_table: remove redundant store to rsdt
  + acpi: gpedump: remove redundant store to gpe_xrupt_info
  + lib: fwts_acpi_tables: remove dead store to facs
  + acpica: fwts_acpica: remove redundant store to length
  + lib: fwts_acpi_tables: remove redundant store to xsdt
  + lib: fwts_acpi_tables: check table to avoid dereferencing
  NULL ptr
  + lib: fwts_acpi_table: Fix FADT update in creation of fake
  FACS table.
  + uefibootpath: fix the wrong type for relative offset range
  path
* Tue Nov 17 2015 mpluskal@suse.com
- Update to 05.11.00
  * Update ACPICA to version 20150930
  * New Features
  + Add in the notion of ACPI compliance tests.
  + MADT subtables: Local SAPIC structure has 3 reserved bytes,
  not 1
  + ACPI: MADT: update GICC flag checks for ACPI 6.0
  + ACPI: MADT: further update to GICC flag checks for 6.0
  + acpi: method: skip scope names in method_evaluate_method
  + acpi: method: add _GPE test
  + acpi: method: add _TSN test
  + acpi: method: add _TFP test
  + acpi: method: add _EC test
  + acpi: method: add _CWS test
  + acpi: method: add _BTH test
  + auto-packager: mkpackage.sh: add xenial
  + acpi: tpm2: add check for zero control area address (LP:
  [#1506442])
  + securebootcert: change fail to warning when MS UEFI CA not
  found in DB
  + lib: fwts_uefi: add BMC device path define
  + uefidump: add dumping the BMC device path
  + uefibootpath: add test for the BMC device path
  + lib: fwts_uefi: add the URI device path define
  + uefibootpath: add test for the URI device path
  + uefidump: add dumping for the URI device path
  + lib: fwts_uefi: add the UFS device path define
  + uefidump: add dumping for the UFS device path
  + uefibootpath: add test for the UFS device path
  * Fixed Bugs
  + dmi: dmicheck: fix SMBIOS issues on aarch64 systems
  + acpidump: add missing reserved fields to MADT structures
  + cpufreq: the calibration is taking a long time, make it
  faster
  + acpi: tcpa: replace tab with spaces to fix formatting
  alignment
* Wed Sep 23 2015 mpluskal@suse.com
- Update to 05.09.00
  * Update ACPICA to version 20150717
  * SMBios 3.0.0 tests supported
  * new features:
  + acpi: method: add _CR3 test
  + acpi: method: add _MTL test
  + acpi: method: add _RST test
  + acpi: method: add _PRR test
  + data: klog.json: sync with latest 4.2 kernel messages
    (LP: #1493039)
  + lib: smbios: add smbios version 3.0.0 entry find helper
  + dmicheck: add test for smbios 3.0.0 entry point
  + dmicheck: add error test for SMBIOS 3.0.0 table
  + dmicheck: sync the dmi value test with smbios 3.0.0 spec
  * fixed bugs:
  + acpi: fadt: merge tests for reset register
  + cpu: cpufreq: reduce scope of variables
  + acpi: gpedump: clarify precedence for & and ?
  + lib: fwts_cpu: reduce scope on variables
  + ACPICA: Update to version 20150717 (LP: #1486253)
  + lib: fwts_log: re-work to clean up va_arg scoping
  + uefi: uefirtvariable: clean up cppcheck style warning
  + acpi: rsdp: make OEM ID test less strict
  + fix some spelling mistakes in code and sync fwts-tests
    accordingly
  + cpu: maxfreq: check for unlikely event that no CPUs in cpu
    list
  + acpi: crsdump: fix incorrect use of string size in string
    copies
  + lib: fwts_acpi_tables: add checking for empty table parsing
  + lib: fwts_acpi_table: remove dead initialisation of ptr
  + dmi: dmicheck: fix build error on 32 bit builds
  + Makefile.am: use pkg-config for json-c
  + lib: fwts_smbios: fix the smbios version from uefi always
    zero (LP: #1484023)
  + lib: fwts_scan_efi_systable: fix getting wrong smbios entry
    (LP: #1484046)
  + acpi: dbg2: won't find obj when no namespace device path
    (lp: #1486893)
  + lib: fwts_smbios: add the struct definition for smbios
    3.0.0
  + dmicheck: re-orgainise the smbios entry point check
  + dmicheck: fix the Base Board type range typos
  + auto-packager: mkpackage.sh: remove utopic
* Mon Aug 24 2015 dvaleev@suse.com
- Set exclusive arch to intel architectures (BIOS)
* Thu Aug 20 2015 mpluskal@suse.com
- Update to 15.08.00
  * new features:
    + acpi: tpm2: Add ACPI TPM2 test
    + acpi: method: add support for _CPC revision 2
    + acpi: add support for FPDT table (LP: #1476954)
    + acpi: add ACPI IORT test (LP: #1450440)
    + ACPICA: Update to version 20150717 (LP: #1475733)
    + acpi: Add support for MCHI Table (LP: #1478951)
    + acpi: Add support for STAO Table (LP: #1478957)
    + acpi: Add support for ASF! Table (LP: #1479736)
    + acpi: Add support for WDAT Table (LP: #1480257)
  * fixed bugs
    + acpi: add table names in test description
    + acpi: remove redundant tailing spaces - no functional
    changes
    + acpi: tcpa: fix incorrect comments - no functional changes
    + acpi: method: fix incorrect shift of 64-bit integer in CRS
    + acpi: acpidump: change FADT flag BIT20 to Hardware-reduce
    ACPI
    + acpi: update MADT GIC Distributor Structure and related
    tests
    + acpi: update MADT GICC Structure and related tests
    + acpi: fadt: update fadt_dsdt test with x_dsdt field
    + acpi: fadt: check RESET_REG_SUP before checking the reset
    register
    + acpi: method: refine _AEI control method
    + acpi: method: refine _EVT test
    + fwts: Better options handling for --dump
    + lib: Allow reading ACPI dump file by non-root user
    + acpi: XENV: fix a few spelling mistakes and fix up
    copyright
    + acpi: LPIT: remove duplicate "LPIT" from test description
    + acpi: HPET: fix typo in HPET description field
    + acpi: iort: fix build warning on older versions of GCC
    + lib: fwts_framework: remove dubious total of
  - -show-tests-full
    + acpidump: update mchi to latest revision of MCHI
    specification
    + lib: fix build error on non-Intel platforms
    + acpi: correct ASF! table definitions
    + lib: acpi.h: clean up comments and code - add more
    references
    + cpu/cpufreq: Iterate over the correct number of CPUs
    in test_sw_any
* Tue Jul 14 2015 mpluskal@suse.com
- Update to 15.07.00
  * --uefi and --acpi options renamed to --uefitests and
  - -acpitests
  * ACPI table tests in the acpitables test have been moved into
    specific ACPI tests.
  * acpi: acpidump: update TCPA table and acpidump accordingly
  * acpi: add ACPI TCPA test
  * acpi: add XENV table test
  * lib: fwts_framework: Append "tests" to --uefi and --acpi
  * live-image/fwts-frontend-text: update to --uefitests and
  - -acpitests
  * lib: acpi, acpidump: rename slit tables types
  * lib: acpi: add in new GICC table fwts_acpi_table_gicc_affinity
  * acpi: add SRAT table sanity checking (LP: #1464658)
  * acpi: add BERT table sanity checking (LP: #1464712)
  * lib: acpi: Add in GAS address types
  * acpi: add ECDT table sanity checking (LP: #1464716)
  * lib: acpi: Add support for the SPMI table
  * acpi: add ACPI SPMI table sanity checking (LP: #1465256)
  * acpi: add ACPI SLIT table sanity checking (LP: #1465276)
  * lib: acpi: Add support for the HEST family of ACPI tables
  * acpi: add ACPI HEST table sanity checking (LP: #1465379)
  * acpi: Add BOOT table test (LP: #1465435)
  * acpi: Add DBGP table test (LP: #1465441)
  * acpi: Add DBG2 table test (LP: #1465710)
  * acpi: re-orgainise HPET tests
  * acpi: move MADT test from acpitables into new MADT test
  * acpi: move GTDT test from acpitables into new GTDT test
  * acpi: move XSDT test from acpitables into new XSDT test
  * acpi: move RSDP test from acpitables into new RSDP test
  * acpi: move RSDT test from acpitables into new RSDT test
  * acpi: acpitables: remove no-op MCFG test
  * acpi: move SBST test from acpitables into new SBST test
  * acpi: move FADT test from acpitables into existing FADT test
  * acpi: acpitables: remove redundant acpi table checking
  * acpi: allow various ACPI table tests to run without root access
  * lib: fwts_acpi_tables: fully pad out fixed up ACPI OEM IDs
  * acpi: spcr: add missing white space in error messages
  * acpi: add ACPI ERST test (LP: #1467835)
  * acpi: correct ACPI BGRT table type
  * acpi: add ACPI BGRT test (LP: #1467863)
  * acpi: add ACPI CPEP test (LP: #1467870)
  * acpi: add ACPI FACS test (LP: #1467966)
  * acpi: acpidump: add in missing exponent field to SLIC
  * acpi: add CSRT ACPI Table test (LP: #1470116)
  * acpi: add LPIT ACPI test (LP: #1470184)
  * acpi: add WAET ACPI table test (LP: #1470495)
  * acpi: add SLIC table test (LP: #1470518)
  * acpi: add MSDM table test (LP: #1470538)
  * acpi: add UEFI ACPI data table test (LP: #1471698)
  * bios: os2gap: remove ancient legacy test (LP: #1470573)
- add fwts-no-compiletime.patch (based on patch from acpica)
* Tue Jun 16 2015 mpluskal@suse.com
- Update to 15.06.00
  * lib: acpi: add an acpi category
  * live-image/fwts-frontend-text: add selections of acpi and uefi
    tests
  * acpi: add tests to acpi category
  * acpi: fwts-tests: Remove redundant tailing space and update
    fwts-tests
  * auto-packager: mkpackage.sh: remove lucid
  * auto-packager: mkpackage.sh: add wily
  * acpi: Add SPCR ACPI table check (LP: #1433604)
  * dmi: dmicheck: add 4 new DMI chassis types
  * uefi: uefirtvariable: Add invalid NULL parameter sanity checks
  * lib: fwts_acpi_tables: print correct pathname on error
  * lib: fwts_acpi_tables: set count correctly on error
  * lib: fwts_acpi_tables: only attempt to open a dumpfile if name
    is defined
  * pci: aspm: check that a table exists, fixes segv on arm64
  * lib: fwts_smbios: only scan memory for DMI table if x86
  * acpi: spcr: remove unnecessary include files and fix ARM build
    issue
  * pci: maxreadreq: skip test if /sys/bus/pci/devices is not
    available
  * acpi: spcr: issue a passed message if SPCR test passes
  * lib: fwts_alloc: provide fallback low memory allocator strategy
    (LP: #1452168)
  * bios: mtrr: fix memory leak on mtrr entries
  * hotkey: only process reads of hotkey events that are at least
    the correct length
  * uefi: uefirtvariable: fix incorrect buffer size being passed
  * lib: fwts_acpi_tables: enforce stricter table loading checks
  * lib: acpica: explicitly set buffer to NULL to remove cppcheck
    warning
  * acpica: fwts_iasl_interface: clean up static analyzer warning
    on freopen
  * lib: fwts_pipe: clean up static analyzer warning on freopen
  * uefi: efi_runtime: eliminate confusing error message of
    get_variable
  * acpi: method: _PRS is not mandatory method
  * acpi: acpitables: FADT: Ignore fields at offset 46 through 108
    for HW_REDUCED_ACPI
  * efi_runtime: get_nextvariablename: Fix bug of name string copy
  * fwts: Add fwts_firmware_has_features
  * fwts: Only run firmware detection once
  * fwts: Allow tests to be conditional on available features
  * fwts: Print names of missing features, rather than a cryptic
    bitmask
  * fwts: Add FWTS_FW_FEATURE_DEVICETREE
  * fwts: Add OPAL firmware type
  * cpu/cpufreq: Don't reparse cpu information
  * cpu/cpufreq: hz_almost_equal is unused if !FWTS_ARCH_INTEL
  * cpu/cpufreq: Add a separate cpufreq consistency test
  * cpu/cpufreq: Add test for duplicate entries in cpufreq tables
  * cpu/cpufreq: Do bios limit and claimed max checks as separate
    tests
  * cpu/cpufreq: Refactor CPU performance tests
  * cpu/cpufreq: Always check that cpufreq changes have taken
  * fwts: Use linux perf counters for cpu benchmarking
  * fwts: Use gettimeofday for cpu benchmark
  * fwts: scale cpu benchmark results to one second
  * cpu/cpufreq: Only run performance tests on master threads
* Sat May  9 2015 jengelh@inai.de
- Drop unnecessary ldconfig call: there are no libraries shipped
  in the standard search paths.
- Pacify rpmlint warning about devel-file-in-non-devel-package
* Wed Apr 22 2015 mpluskal@suse.com
- Update to 15.03.01
  * uefi: uefirttime: Add tests to exercise invalid parameters
  * acpi: acpitables: add GTDT checking
  * lib: fwts_acpi_tables: load tables from /sys (LP: #1437043)
  * efi_runtime: ensure we don't allocate a zero byte buffer
    (LP: #1429890)]
  * acpi: acpitables: make length and skip signed to handle -ve
    underflow (LP: #1435272)
  * uefi: uefidump: don't dump non-printable variable contents
    (LP: #1435346)
  * uefi: uefirtmisc: Add null count argument check for
    GetNextHighMonotonicCount
  * uefirtauthvar: return error when get mismatch size
  * uefirtauthvar: dependency checking for existence of test data (
    (LP: #1434408)
  * uefirtauthvar: remove duplicate authenticated attribute test
    (LP: #1432752)
* Sun Mar 29 2015 mpluskal@suse.com
- Update to 15.03.00
- Remove patches fwts-linking.patch and fwts-opensuse.patch
- Add json-c-includes.patch
* Wed Feb  1 2012 crrodriguez@opensuse.org
- Fix linking
* Mon Dec 12 2011 crrodriguez@opensuse.org
- Update to version fwts-0.24.13
* Wed Sep  1 2010 stepan@coresystems.de
- initial package of fwts (version 0.18.1)
